@@ -68,9 +68,8 @@ QStringList getTagBrNormal()
    #undef qL
 }
 
-GettextExportPlugin::GettextExportPlugin(short wrapWidth, short trailingNewLines)
+GettextExportPlugin::GettextExportPlugin(short wrapWidth)
     : m_wrapWidth(wrapWidth)
-    , m_trailingNewLines(trailingNewLines)
 {
 }
 
@@ -133,10 +132,6 @@ ConversionStatus GettextExportPlugin::save(QIODevice* device,
         stream << '\n' << data << '\n';
     }
 
-    for (short i = 0; i <= m_trailingNewLines; ++i) {
-        stream << '\n';
-    }
-
     return OK;
 }
 
