@@ -12,6 +12,7 @@
 
 #include "lokalizesubwindowbase.h"
 #include "pos.h"
+#include "qaview.h"
 #include "rule.h"
 
 #include <QDockWidget>
@@ -77,7 +78,7 @@ public Q_SLOTS:
     Q_SCRIPTABLE bool findGuiTextPackage(QString text, QString package);
     void fileSearchNext();
     void stopSearch();
-    void massReplace(const QRegExp &what, const QString& with);
+    void massReplace(const QRegularExpression &what, const QString& with);
 
 private Q_SLOTS:
     void searchJobDone(SearchJob*);
@@ -93,20 +94,19 @@ private:
 
 
 private:
-    Ui_FileSearchOptions* ui_fileSearchOptions;
+    Ui_FileSearchOptions* ui_fileSearchOptions{nullptr};
 
-    FileSearchModel* m_model;
-    //TMResultsSortFilterProxyModel *m_proxyModel;
-    SearchFileListView* m_searchFileListView;
-    MassReplaceView* m_massReplaceView;
-    QaView* m_qaView;
+    FileSearchModel* m_model{nullptr};
+    SearchFileListView* m_searchFileListView{nullptr};
+    MassReplaceView* m_massReplaceView{nullptr};
+    QaView* m_qaView{new QaView(this)};
 
     QVector<QRunnable*> m_runningJobs;
 
     //to avoid results from previous search showing up in the new one
-    int m_lastSearchNumber;
+    int m_lastSearchNumber{0};
 
-    int m_dbusId;
+    int m_dbusId{-1};
     static QList<int> ids;
 };
 
@@ -116,7 +116,7 @@ struct FileSearchResult {
     QString source;
     QString target;
 
-    bool isApproved;
+    bool isApproved{};
     TargetState state;
     //Phase activePhase;
 
@@ -133,7 +133,7 @@ typedef QMap<QString, QVector<FileSearchResult> > FileSearchResults;
 struct SearchResult: public FileSearchResult {
     QString filepath;
 
-    SearchResult(const FileSearchResult& fsr): FileSearchResult(fsr) {}
+    explicit SearchResult(const FileSearchResult& fsr): FileSearchResult(fsr) {}
     SearchResult() {}
 };
 
@@ -186,11 +186,11 @@ public:
     void clear();
 
 public Q_SLOTS:
-    void setReplacePreview(const QRegExp&, const QString&);
+    void setReplacePreview(const QRegularExpression&, const QString&);
 
 private:
     SearchResults m_searchResults;
-    QRegExp m_replaceWhat;
+    QRegularExpression m_replaceWhat;
     QString m_replaceWith;
 };
 
@@ -216,9 +216,9 @@ Q_SIGNALS:
     void fileOpenRequested(const QString& filePath, const bool setAsActive);
 
 private:
-    QTreeView* m_browser;
-    QLabel* m_background;
-    QStringListModel* m_model;
+    QTreeView* m_browser{};
+    QLabel* m_background{};
+    QStringListModel* m_model{};
 };
 
 class Ui_MassReplaceOptions;
@@ -234,8 +234,8 @@ public:
     void deactivatePreview();
 
 Q_SIGNALS:
-    void previewRequested(const QRegExp&, const QString&);
-    void replaceRequested(const QRegExp&, const QString&);
+    void previewRequested(const QRegularExpression&, const QString&);
+    void replaceRequested(const QRegularExpression&, const QString&);
 
 private Q_SLOTS:
     void requestPreview(bool enable);
@@ -243,22 +243,23 @@ private Q_SLOTS:
     void requestReplace();
 
 private:
-    Ui_MassReplaceOptions* ui;
+    Ui_MassReplaceOptions* ui{};
 };
 
 struct SearchParams {
-    QRegExp sourcePattern;
-    QRegExp targetPattern;
-    QRegExp notesPattern;
+    QString sourcePattern;
+    QString targetPattern;
+    QRegularExpression::PatternOptions regExOptions{};
+    bool isRegEx{false}; // indicates source/targetPattern are regular expressions
 
-    bool invertSource;
-    bool invertTarget;
+    bool invertSource{false};
+    bool invertTarget{false};
 
     bool states[StateCount];
 
     bool isEmpty() const;
 
-    SearchParams(): invertSource(false), invertTarget(false)
+    SearchParams()
     {
         memset(states, 0, sizeof(states));
     }
@@ -284,11 +285,11 @@ public:
     QStringList files;
     SearchParams searchParams;
     QVector<Rule> rules;
-    int searchNumber;
+    int searchNumber{};
 
     SearchResults results; //plain
 
-    int m_size;
+    int m_size{0};
 };
 
 /// @short replace in files
@@ -298,7 +299,7 @@ class MassReplaceJob: public QObject, public QRunnable
 public:
     explicit MassReplaceJob(const SearchResults& srs,
                             int pos,
-                            const QRegExp& s,
+                            const QRegularExpression& s,
                             const QString& r,
                             //int sn,
                             QObject* parent = nullptr);
@@ -311,8 +312,8 @@ protected:
     void run() override;
 public:
     SearchResults searchResults;
-    int globalPos;
-    QRegExp replaceWhat;
+    int globalPos{};
+    QRegularExpression replaceWhat;
     QString replaceWith;
 };
 
