@@ -141,7 +141,7 @@ void GlossarySortFilterProxyModel::setFilterRegExp(const QString& s)
         return;
 
     //static const QRegExp lettersOnly("^[a-z]");
-    QSortFilterProxyModel::setFilterRegExp(s);
+    QSortFilterProxyModel::setFilterRegularExpression(s);
 
     fetchMore(QModelIndex());
 }
@@ -261,18 +261,18 @@ QByteArray Glossary::generateNewId()
 
     QString authorId(Settings::authorName().toLower());
     authorId.replace(QLatin1Char(' '), QLatin1Char('_'));
-    QRegExp rx(QLatin1Char('^') + authorId + QStringLiteral("\\-([0-9]*)$"));
+    const QRegularExpression rx(QRegularExpression::anchoredPattern(QLatin1Char('^') + authorId + QStringLiteral("\\-([0-9]*)$")));
 
 
-    for (const QByteArray& id : qAsConst(m_idsForEntriesById)) {
-        if (rx.exactMatch(QString::fromLatin1(id)))
-            busyIdNumbers.append(rx.cap(1).toInt());
+    for (const QByteArray& id : std::as_const(m_idsForEntriesById)) {
+        if (const auto match = rx.match(QString::fromLatin1(id)); match.hasMatch())
+            busyIdNumbers.append(match.capturedView(1).toInt());
     }
 
     int i = removedIds.size();
     while (--i >= 0) {
-        if (rx.exactMatch(QString::fromLatin1(removedIds.at(i))))
-            busyIdNumbers.append(rx.cap(1).toInt());
+        if (const auto match = rx.match(QString::fromLatin1(removedIds.at(i))); match.hasMatch())
+            busyIdNumbers.append(match.capturedView(1).toInt());
     }
 
     if (!busyIdNumbers.isEmpty()) {
@@ -302,7 +302,7 @@ QByteArray Glossary::id(int index) const
 QStringList Glossary::terms(const QByteArray& id, const QString& language) const
 {
     QString minusLang = language; minusLang.replace(QLatin1Char('_'), QLatin1Char('-'));
-    QStringRef soleLang = language.leftRef(2);
+    const auto soleLang = QStringView(language).left(2);
     QStringList result;
     QDomElement n = m_entriesById.value(id).firstChildElement(langSet);
     while (!n.isNull()) {
@@ -334,7 +334,7 @@ static void getElementsForTermLangIndex(QDomElement termEntry, QString& lang, in
                                         QDomElement& termElement)
 {
     QString minusLang = lang; minusLang.replace(QLatin1Char('_'), QLatin1Char('-'));
-    QStringRef soleLang = lang.leftRef(2);
+    const auto soleLang = QStringView(lang).left(2);
 
     QDomElement n = termEntry.firstChildElement(langSet);
     QDomDocument document = n.ownerDocument();
