@@ -222,7 +222,7 @@ GlossaryWindow::GlossaryWindow(QWidget *parent)
     m_filterEdit->setPlaceholderText(i18n("Quick search..."));
     m_filterEdit->setFocus();
     m_filterEdit->setToolTip(i18nc("@info:tooltip", "Activated by Ctrl+L. Accepts regular expressions"));
-    new QShortcut(Qt::CTRL + Qt::Key_L, this, SLOT(setFocus()), nullptr, Qt::WidgetWithChildrenShortcut);
+    new QShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_L), this, SLOT(setFocus()), nullptr, Qt::WidgetWithChildrenShortcut);
     connect(m_filterEdit, &QLineEdit::textChanged, m_proxyModel, &GlossaryNS::GlossarySortFilterProxyModel::setFilterRegExp);
 
     layout->addWidget(m_filterEdit);
@@ -486,7 +486,6 @@ bool GlossaryWindow::queryClose()
     if (glossary->isClean())
         return true;
 
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     switch (KMessageBox::warningTwoActionsCancel(
                 this,
                 i18nc("@info", "The glossary contains unsaved changes.\n"
@@ -502,20 +501,6 @@ bool GlossaryWindow::queryClose()
     default:
         return false;
     }
-#else
-    switch (KMessageBox::warningYesNoCancel(this,
-                                            i18nc("@info", "The glossary contains unsaved changes.\n\
-Do you want to save your changes or discard them?"), i18nc("@title:window", "Warning"),
-                                            KStandardGuiItem::save(), KStandardGuiItem::discard())) {
-    case KMessageBox::Yes:
-        return save();
-    case KMessageBox::No:
-        restore();
-        return true;
-    default:
-        return false;
-    }
-#endif
 }
 
 
