@@ -54,8 +54,6 @@ int main(int argc, char **argv)
     TM::threadPool()->setMaxThreadCount(1);
     TM::threadPool()->setExpiryTimeout(-1);
     QThreadPool::globalInstance()->setMaxThreadCount(1);
-    // Fixes blurry icons with fractional scaling, see https://phabricator.kde.org/D29376
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
     KCrash::initialize();
     KLocalizedString::setApplicationDomain("lokalize");
@@ -91,8 +89,6 @@ int main(int argc, char **argv)
     qCDebug(LOKALIZE_LOG) << qRegisterMetaType<DocPos>();
     qCDebug(LOKALIZE_LOG) << qRegisterMetaType<InlineTag>();
     qCDebug(LOKALIZE_LOG) << qRegisterMetaType<CatalogString>();
-    qRegisterMetaTypeStreamOperators<InlineTag>("InlineTag");
-    qRegisterMetaTypeStreamOperators<CatalogString>("CatalogString");
     qAddPostRoutine(&cleanupSpellers);
 
     const KDBusService dbusService(KDBusService::Multiple);
