@@ -23,12 +23,12 @@
 #include <QSqlQuery>
 #include <QSqlError>
 #include <QStringBuilder>
-#include <QRegExp>
 #include <QMap>
 #include <QStandardPaths>
 #include <QFile>
 #include <QElapsedTimer>
 #include <QDir>
+#include <QRegularExpression>
 
 #include <iostream>
 
@@ -67,11 +67,11 @@ static qlonglong reusedTMSourceEntryCount = 0;
 **/
 static void doSplit(QString& cleanEn,
                     QStringList& words,
-                    QRegExp& rxClean1,
+                    QRegularExpression& rxClean1,
                     const QString& accel
                    )
 {
-    static QRegExp rxSplit(QStringLiteral("\\W+|\\d+"));
+    static const QRegularExpression rxSplit(QStringLiteral("\\W+|\\d+"));
 
     if (!rxClean1.pattern().isEmpty())
         cleanEn.replace(rxClean1, QStringLiteral(" "));
@@ -138,7 +138,7 @@ static qlonglong getFileId(const QString& path,
 
 
 static void addToIndex(qlonglong sourceId, QString sourceString,
-                       QRegExp& rxClean1, const QString& accel, QSqlDatabase& db)
+                       QRegularExpression& rxClean1, const QString& accel, QSqlDatabase& db)
 {
     QStringList words;
     doSplit(sourceString, words, rxClean1, accel);
@@ -173,9 +173,9 @@ static void addToIndex(qlonglong sourceId, QString sourceString,
             }
             query1.clear();
 
-            if (arr.contains(' ' + sourceIdStr + ' ')
-                || arr.startsWith(sourceIdStr + ' ')
-                || arr.endsWith(' ' + sourceIdStr)
+            if (arr.contains(QByteArray(' ' + sourceIdStr + ' '))
+                || arr.startsWith(QByteArray(sourceIdStr + ' '))
+                || arr.endsWith(QByteArray(' ' + sourceIdStr))
                 || arr == sourceIdStr)
                 return;//this string is already indexed
 
@@ -213,7 +213,7 @@ static void addToIndex(qlonglong sourceId, QString sourceString,
  * 'good' entries using it but the entry specified with mainId
  */
 static void removeFromIndex(qlonglong mainId, qlonglong sourceId, QString sourceString,
-                            QRegExp& rxClean1, const QString& accel, QSqlDatabase& db)
+                            QRegularExpression& rxClean1, const QString& accel, QSqlDatabase& db)
 {
     QStringList words;
     doSplit(sourceString, words, rxClean1, accel);
@@ -268,11 +268,11 @@ static void removeFromIndex(qlonglong mainId, qlonglong sourceId, QString source
         }
         query1.clear();
 
-        if (arr.contains(' ' + sourceIdStr + ' '))
-            arr.replace(' ' + sourceIdStr + ' ', " ");
-        else if (arr.startsWith(sourceIdStr + ' '))
+        if (arr.contains(QByteArray(' ' + sourceIdStr + ' ')))
+            arr.replace(QByteArray(' ' + sourceIdStr + ' '), " ");
+        else if (arr.startsWith(QByteArray(sourceIdStr + ' ')))
             arr.remove(0, sourceIdStr.size() + 1);
-        else if (arr.endsWith(' ' + sourceIdStr))
+        else if (arr.endsWith(QByteArray(' ' + sourceIdStr)))
             arr.chop(sourceIdStr.size() + 1);
         else if (arr == sourceIdStr)
             arr.clear();
@@ -288,7 +288,7 @@ static void removeFromIndex(qlonglong mainId, qlonglong sourceId, QString source
     }
 }
 
-static bool doRemoveEntry(qlonglong mainId, QRegExp& rxClean1, const QString& accel, QSqlDatabase& db)
+static bool doRemoveEntry(qlonglong mainId, QRegularExpression& rxClean1, const QString& accel, QSqlDatabase& db)
 {
     QSqlQuery query1(db);
 
@@ -392,7 +392,7 @@ static bool doInsertEntry(CatalogString source,
                           bool approved,
                           qlonglong fileId,
                           QSqlDatabase& db,
-                          QRegExp& rxClean1,//cleaning regexps for word index update
+                          QRegularExpression& rxClean1,//cleaning regexps for word index update
                           const QString& accel,
                           qlonglong priorId,
                           qlonglong& mainId
@@ -972,7 +972,7 @@ void OpenDBJob::run()
 
         if (m_type == TM::Local) {
             QSqlDatabase db = QSqlDatabase::addDatabase(QStringLiteral("QSQLITE"), connectionName);
-            QString dbFolder = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
+            QString dbFolder = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
             QFileInfo fileInfo(dbFolder);
             if (!fileInfo.exists(dbFolder)) fileInfo.absoluteDir().mkpath(fileInfo.fileName());
             db.setDatabaseName(dbFolder + QLatin1Char('/') + m_dbName + QLatin1String(TM_DATABASE_EXTENSION));
@@ -1006,7 +1006,7 @@ void OpenDBJob::run()
             }
 
             if (!m_connParams.isFilled()) {
-                QFile rdb(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + m_dbName + QLatin1String(REMOTETM_DATABASE_EXTENSION));
+                QFile rdb(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + m_dbName + QLatin1String(REMOTETM_DATABASE_EXTENSION));
                 if (!rdb.open(QIODevice::ReadOnly | QIODevice::Text)) {
                     Q_EMIT done(this);
                     return;
@@ -1118,7 +1118,7 @@ SelectJob::SelectJob(const CatalogString& source,
     //qCDebug(LOKALIZE_LOG)<<"selectjob"<<dbName<<m_source.string;
 }
 
-inline QMap<uint, qlonglong> invertMap(const QMap<qlonglong, uint>& source)
+inline QMultiMap<uint, qlonglong> invertMap(const QMap<qlonglong, uint>& source)
 {
     //uses the fact that map has its keys always sorted
     QMultiMap<uint, qlonglong> sortingMap;
@@ -1182,19 +1182,17 @@ bool SelectJob::doSelect(QSqlDatabase& db,
     QString tmp = c.markup;
     if (!c.markup.isEmpty())
         tmp += QLatin1Char('|');
-    QRegExp rxSplit(QLatin1Char('(') + tmp + QStringLiteral("\\W+|\\d+)+"));
+    const QRegularExpression rxSplit(QLatin1Char('(') + tmp + QStringLiteral("\\W+|\\d+)+"));
 
     QString sourceClean(m_source.string);
     sourceClean.remove(c.accel);
     //split m_english for use in wordDiff later--all words are needed so we cant use list we already have
     QStringList englishList(sourceClean.toLower().split(rxSplit, Qt::SkipEmptyParts));
-    static QRegExp delPart(QStringLiteral("<KBABELDEL>*</KBABELDEL>"), Qt::CaseSensitive, QRegExp::Wildcard);
-    static QRegExp addPart(QStringLiteral("<KBABELADD>*</KBABELADD>"), Qt::CaseSensitive, QRegExp::Wildcard);
-    delPart.setMinimal(true);
-    addPart.setMinimal(true);
+    static const QRegularExpression delPart(QRegularExpression::wildcardToRegularExpression(QStringLiteral("<KBABELDEL>*</KBABELDEL>"), QRegularExpression::UnanchoredWildcardConversion), QRegularExpression::InvertedGreedinessOption);
+    static const QRegularExpression addPart(QRegularExpression::wildcardToRegularExpression(QStringLiteral("<KBABELADD>*</KBABELADD>"), QRegularExpression::UnanchoredWildcardConversion), QRegularExpression::InvertedGreedinessOption);
 
     //QList<uint> concordanceLevels=sortedUniqueValues(occurencies); //we start from entries with higher word-concordance level
-    QMap<uint, qlonglong> concordanceLevelToIds = invertMap(occurencies);
+    QMultiMap<uint, qlonglong> concordanceLevelToIds = invertMap(occurencies);
     if (concordanceLevelToIds.isEmpty())
         return false;
     bool seen85 = false;
@@ -1253,19 +1251,29 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                 int pos = 0;
                 int delSubStrCount = 0;
                 int delLen = 0;
-                while ((pos = delPart.indexIn(result, pos)) != -1) {
+                while (true) {
+                    const auto match = delPart.match(result, pos);
+                    if (!match.hasMatch()) {
+                        break;
+                    }
+                    pos = match.capturedStart();
                     //qCWarning(LOKALIZE_LOG) <<"SelectJob:  match del "<<delPart.cap(0);
-                    delLen += delPart.matchedLength() - 23;
+                    delLen += match.capturedLength() - 23;
                     ++delSubStrCount;
-                    pos += delPart.matchedLength();
+                    pos += match.capturedLength();
                 }
                 pos = 0;
                 int addSubStrCount = 0;
                 int addLen = 0;
-                while ((pos = addPart.indexIn(result, pos)) != -1) {
-                    addLen += addPart.matchedLength() - 23;
+                while (true) {
+                    const auto match = addPart.match(result, pos);
+                    if (!match.hasMatch()) {
+                        break;
+                    }
+                    pos = match.capturedStart();
+                    addLen += match.capturedLength() - 23;
                     ++addSubStrCount;
-                    pos += addPart.matchedLength();
+                    pos += match.capturedLength();
                 }
 
                 //allLen - length of suggestion
@@ -1387,7 +1395,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                 //eliminate same targets from different files
                 QHash<QString, int> hash;
                 int oldCount = m_entries.size();
-                QMap<TMEntry, bool>::const_iterator it = sortedEntryList.constEnd();
+                auto it = sortedEntryList.constEnd();
                 if (sortedEntryList.size()) while (true) {
                         --it;
                         const TMEntry& e = it.key();
@@ -1433,7 +1441,7 @@ void SelectJob::run()
     //qCDebug(LOKALIZE_LOG)<<"select started 2"<<m_dbName<<m_source.string;
 
     TMConfig c = getConfig(db);
-    QRegExp rxClean1(c.markup); rxClean1.setMinimal(true);
+    QRegularExpression rxClean1(c.markup, QRegularExpression::InvertedGreedinessOption);
 
     QString cleanSource = m_source.string;
     QStringList words;
@@ -1508,12 +1516,12 @@ void ScanJob::run()
         return;
     //initSqliteDb(db);
     TMConfig c = getConfig(db, true);
-    QRegExp rxClean1(c.markup); rxClean1.setMinimal(true);
+    QRegularExpression rxClean1(c.markup, QRegularExpression::InvertedGreedinessOption);
 
     Catalog catalog(nullptr);
     if (Q_LIKELY(catalog.loadFromUrl(m_filePath, QString(), &m_size, /*no auto save*/true) == 0)) {
         if (c.targetLangCode != catalog.targetLangCode()) {
-            qCWarning(LOKALIZE_LOG) << "not indexing file because target languages don't match:" << c.targetLangCode << "in TM vs" << catalog.targetLangCode() << "in file";
+            qCWarning(LOKALIZE_LOG) << "not indexing file" << m_filePath << "because target languages don't match:" << c.targetLangCode << "in TM vs" << catalog.targetLangCode() << "in file";
             return;
         }
         qlonglong priorId = -1;
@@ -1644,7 +1652,7 @@ void RemoveJob::run()
 
     //cleaning regexps for word index update
     TMConfig c = getConfig(db);
-    QRegExp rxClean1(c.markup); rxClean1.setMinimal(true);
+    QRegularExpression rxClean1(c.markup, QRegularExpression::InvertedGreedinessOption);
 
     if (!doRemoveEntry(m_entry.id, rxClean1, c.accel, db))
         qCWarning(LOKALIZE_LOG) << "error removing entry" << m_entry.dbName << m_entry.source.string << m_entry.target.string;
@@ -1681,7 +1689,7 @@ void UpdateJob::run()
 
     //cleaning regexps for word index update
     TMConfig c = getConfig(db);
-    QRegExp rxClean1(c.markup); rxClean1.setMinimal(true);
+    QRegularExpression rxClean1(c.markup, QRegularExpression::InvertedGreedinessOption);
 
 
     qlonglong fileId = getFileId(m_filePath, db);
@@ -1701,7 +1709,6 @@ void UpdateJob::run()
 
 //BEGIN TMX
 
-#include <QXmlDefaultHandler>
 #include <QXmlStreamReader>
 
 /**
@@ -1735,7 +1742,7 @@ public:
 
 private:
     QSqlDatabase db;
-    QRegExp rxClean1;
+    QRegularExpression rxClean1;
     QString accel;
 
     int m_hits{0};
@@ -1764,7 +1771,8 @@ TmxParser::TmxParser(const QString& dbName)
     , m_dbLangCode(Project::instance()->langCode().toLower())
 {
     TMConfig c = getConfig(db);
-    rxClean1.setPattern(c.markup); rxClean1.setMinimal(true);
+    rxClean1.setPattern(c.markup);
+    rxClean1.setPatternOptions(QRegularExpression::InvertedGreedinessOption);
     accel = c.accel;
 }
 
