@@ -99,7 +99,7 @@ static DiffInfo getDiffInfo(const QString& diff)
         } else {
             if (state != '+') {
                 d.old.append(diff.at(pos));
-                d.old2DiffClean.append(d.diffIndex.count());
+                d.old2DiffClean.append(d.diffIndex.size());
             }
             d.diffIndex.append(state);
             d.diffClean.append(diff.at(pos));
@@ -140,7 +140,7 @@ TMView::TMView(QWidget* parent, Catalog* catalog, const QVector<QAction*>& actio
 
 TMView::~TMView()
 {
-    for (auto job : qAsConst(m_jobs)) {
+    for (auto job : std::as_const(m_jobs)) {
         [[maybe_unused]] const bool result = TM::threadPool()->tryTake(job);
     }
 }
@@ -198,7 +198,7 @@ void TMView::slotFileLoaded(const QString& filePath)
         return;
 
     m_cache.clear();
-    for (auto job : qAsConst(m_jobs)) {
+    for (auto job : std::as_const(m_jobs)) {
         [[maybe_unused]] const bool result = TM::threadPool()->tryTake(job);
     }
     m_jobs.clear();
@@ -291,7 +291,7 @@ void TMView::slotBatchSelectDone()
     }
 
     KNotification *notification = new KNotification(QStringLiteral("BatchTranslationCompleted"));
-    notification->setWidget(this);
+    notification->setWindow(window()->windowHandle());
     notification->setText(msg);
     notification->sendEvent();
 }
@@ -306,7 +306,7 @@ void TMView::slotBatchTranslate()
         return slotBatchSelectDone();
 
     KNotification *notification = new KNotification(QStringLiteral("BatchTranslationScheduled"));
-    notification->setWidget(this);
+    notification->setWindow(window()->windowHandle());
     notification->setText(i18nc("@info", "Batch translation has been scheduled."));
     notification->sendEvent();
 }
@@ -321,7 +321,7 @@ void TMView::slotBatchTranslateFuzzy()
         slotBatchSelectDone();
 
     KNotification *notification = new KNotification(QStringLiteral("BatchTranslationScheduled"));
-    notification->setWidget(this);
+    notification->setWindow(window()->windowHandle());
     notification->setText(i18nc("@info", "Batch translation has been scheduled."));
     notification->sendEvent();
 }
@@ -336,7 +336,7 @@ void TMView::slotNewEntryDisplayed(const DocPosition& pos)
     if (m_catalog->numberOfEntries() <= pos.entry)
         return;//because of Qt::QueuedConnection
 
-    for (auto job : qAsConst(m_jobs)) {
+    for (auto job : std::as_const(m_jobs)) {
         [[maybe_unused]] const bool result = TM::threadPool()->tryTake(job);
     }
 
@@ -554,19 +554,12 @@ bool TMView::event(QEvent *event)
 
 void TMView::removeEntry(const TMEntry& e)
 {
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (KMessageBox::PrimaryAction == KMessageBox::questionTwoActions(
                 this,
                 i18n("<html>Do you really want to remove this entry:<br/><i>%1</i><br/>from translation memory %2?</html>",  e.target.string.toHtmlEscaped(), e.dbName),
                 i18nc("@title:window", "Translation Memory Entry Removal"),
                 KStandardGuiItem::remove(),
                 KStandardGuiItem::cancel())) {
-#else
-    if (KMessageBox::Yes == KMessageBox::questionYesNo(
-                this,
-                i18n("<html>Do you really want to remove this entry:<br/><i>%1</i><br/>from translation memory %2?</html>",  e.target.string.toHtmlEscaped(), e.dbName),
-                i18nc("@title:window", "Translation Memory Entry Removal"))) {
-#endif
         RemoveJob* job = new RemoveJob(e);
         connect(job, SIGNAL(done()), this, SLOT(slotNewEntryDisplayed()));
         TM::threadPool()->start(job, REMOVE);
@@ -628,7 +621,6 @@ void TMView::contextMenu(const QPoint& pos)
         removeEntry(*e);
     } else if (r->data().toInt() == Open) {
         Q_EMIT fileOpenRequested(e->file, e->source.string, e->ctxt, true);
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     } else if ((r->data().toInt() == RemoveFile)
                && KMessageBox::PrimaryAction == KMessageBox::questionTwoActions(
                    this,
@@ -636,11 +628,6 @@ void TMView::contextMenu(const QPoint& pos)
                    i18nc("@title:window", "Translation Memory Missing File Removal"),
                    KStandardGuiItem::remove(),
                    KStandardGuiItem::cancel())) {
-#else
-    } else if ((r->data().toInt() == RemoveFile) &&
-               KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("<html>Do you really want to remove this missing file:<br/><i>%1</i><br/>from translation memory %2?</html>",  e->file, e->dbName),
-                       i18nc("@title:window", "Translation Memory Missing File Removal"))) {
-#endif
         deleteFile(*e, false);
     }
 }
@@ -652,15 +639,22 @@ void TMView::contextMenu(const QPoint& pos)
  */
 static int nextPlacableIn(const QString& old, int start, QString& cap)
 {
-    static QRegExp rxNum(QStringLiteral("[\\d\\.\\%]+"));
-    static QRegExp rxAbbr(QStringLiteral("\\w+"));
+    static const QRegularExpression rxNum(QStringLiteral("[\\d\\.\\%]+"));
+    static const QRegularExpression rxAbbr(QStringLiteral("\\w+"));
 
-    int numPos = rxNum.indexIn(old, start);
+    const auto numMatch = rxNum.match(old, start);
 //    int abbrPos=rxAbbr.indexIn(old,start);
+    QRegularExpressionMatch abbrMatch;
     int abbrPos = start;
     //qCWarning(LOKALIZE_LOG)<<"seeing"<<old.size()<<old;
-    while (((abbrPos = rxAbbr.indexIn(old, abbrPos)) != -1)) {
-        QString word = rxAbbr.cap(0);
+    while (true) {
+        abbrMatch = rxAbbr.match(old, abbrPos);
+        if (!abbrMatch.hasMatch()) {
+            abbrPos = -1;
+            break;
+        }
+        abbrPos = abbrMatch.capturedStart();
+        QString word = abbrMatch.captured(0);
         //check if tail contains uppoer case characters
         const QChar* c = word.unicode() + 1;
         int i = word.size() - 1;
@@ -668,19 +662,19 @@ static int nextPlacableIn(const QString& old, int start, QString& cap)
             if ((c++)->isUpper())
                 break;
         }
-        abbrPos += rxAbbr.matchedLength();
+        abbrPos += abbrMatch.capturedLength();
     }
 
-    int pos = qMin(numPos, abbrPos);
+    int pos = qMin(numMatch.capturedStart(), abbrPos);
     if (pos == -1)
-        pos = qMax(numPos, abbrPos);
+        pos = qMax(numMatch.capturedStart(), abbrPos);
 
-//     if (pos==numPos)
-//         cap=rxNum.cap(0);
+//     if (pos==numMatch.capturedStart())
+//         cap=numMatch.captured(0);
 //     else
 //         cap=rxAbbr.cap(0);
 
-    cap = (pos == numPos ? rxNum : rxAbbr).cap(0);
+    cap = pos == numMatch.capturedStart() ? numMatch.captured(0) : abbrMatch.captured(0);
     //qCWarning(LOKALIZE_LOG)<<cap;
 
     return pos;
@@ -705,18 +699,30 @@ CatalogString TM::targetAdapted(const TMEntry& entry, const CatalogString& ref)
     //QString english=entry.english;
 
 
-    QRegExp rxAdd(QLatin1String("<font style=\"background-color:[^>]*") + Settings::addColor().name() + QLatin1String("[^>]*\">([^>]*)</font>"));
-    QRegExp rxDel(QLatin1String("<font style=\"background-color:[^>]*") + Settings::delColor().name() + QLatin1String("[^>]*\">([^>]*)</font>"));
+    const QRegularExpression rxAdd(QLatin1String("<font style=\"background-color:[^>]*") + Settings::addColor().name() + QLatin1String("[^>]*\">([^>]*)</font>"));
+    const QRegularExpression rxDel(QLatin1String("<font style=\"background-color:[^>]*") + Settings::delColor().name() + QLatin1String("[^>]*\">([^>]*)</font>"));
     //rxAdd.setMinimal(true);
     //rxDel.setMinimal(true);
 
     //first things first
     int pos = 0;
-    while ((pos = rxDel.indexIn(diff, pos)) != -1)
-        diff.replace(pos, rxDel.matchedLength(), QStringLiteral("\tKBABELDEL\t") + rxDel.cap(1) + QStringLiteral("\t/KBABELDEL\t"));
+    while (true) {
+        const auto match = rxDel.match(diff, pos);
+        if (!match.hasMatch()) {
+            break;
+        }
+        pos = match.capturedStart();
+        diff.replace(pos, match.capturedLength(), QStringLiteral("\tKBABELDEL\t") + match.capturedView(1) + QStringLiteral("\t/KBABELDEL\t"));
+    }
     pos = 0;
-    while ((pos = rxAdd.indexIn(diff, pos)) != -1)
-        diff.replace(pos, rxAdd.matchedLength(), QStringLiteral("\tKBABELADD\t") + rxAdd.cap(1) + QStringLiteral("\t/KBABELADD\t"));
+    while (true) {
+        const auto match = rxAdd.match(diff, pos);
+        if (!match.hasMatch()) {
+            break;
+        }
+        pos = match.capturedStart();
+        diff.replace(pos, match.capturedLength(), QStringLiteral("\tKBABELADD\t") + match.capturedView(1) + QStringLiteral("\t/KBABELADD\t"));
+    }
 
     diff.replace(QStringLiteral("&lt;"), QStringLiteral("<"));
     diff.replace(QStringLiteral("&gt;"), QStringLiteral(">"));
@@ -740,14 +746,19 @@ CatalogString TM::targetAdapted(const TMEntry& entry, const CatalogString& ref)
     bool tryMarkup = !entry.target.tags.size() && sameMarkup;
     //search for changed markup
     if (tryMarkup) {
-        QRegExp rxMarkup(entry.markupExpr);
-        rxMarkup.setMinimal(true);
+        const QRegularExpression rxMarkup(entry.markupExpr, QRegularExpression::InvertedGreedinessOption);
         pos = 0;
         int replacingPos = 0;
-        while ((pos = rxMarkup.indexIn(d.old, pos)) != -1) {
+        while (true) {
+            const auto match = rxMarkup.match(d.old, pos);
+            if (!match.hasMatch()) {
+                break;
+            }
+            pos = match.capturedStart();
+
             //qCWarning(LOKALIZE_LOG)<<"size"<<oldM.size()<<pos<<pos+rxMarkup.matchedLength();
             QByteArray diffIndexPart(d.diffIndex.mid(d.old2DiffClean.at(pos),
-                                     d.old2DiffClean.at(pos + rxMarkup.matchedLength() - 1) + 1 - d.old2DiffClean.at(pos)));
+                                     d.old2DiffClean.at(pos + match.capturedLength() - 1) + 1 - d.old2DiffClean.at(pos)));
             //qCWarning(LOKALIZE_LOG)<<"diffMPart"<<diffMPart;
             if (diffIndexPart.contains('-')
                 || diffIndexPart.contains('+')) {
@@ -761,30 +772,30 @@ CatalogString TM::targetAdapted(const TMEntry& entry, const CatalogString& ref)
                 }
 
                 //replace first ocurrence
-                int tmp = target.string.indexOf(rxMarkup.cap(0), replacingPos);
+                int tmp = target.string.indexOf(match.capturedView(0), replacingPos);
                 if (tmp != -1) {
                     target.replace(tmp,
-                                   rxMarkup.cap(0).size(),
+                                   match.capturedView(0).size(),
                                    newMarkup);
                     replacingPos = tmp;
                     //qCWarning(LOKALIZE_LOG)<<"d.old"<<rxMarkup.cap(0)<<"new"<<newMarkup;
 
                     //avoid trying this part again
-                    tmp = d.old2DiffClean.at(pos + rxMarkup.matchedLength() - 1);
+                    tmp = d.old2DiffClean.at(pos + match.capturedLength() - 1);
                     while (--tmp >= d.old2DiffClean.at(pos))
                         d.diffIndex[tmp] = 'M';
                     //qCWarning(LOKALIZE_LOG)<<"M"<<diffM;
                 }
             }
 
-            pos += rxMarkup.matchedLength();
+            pos += match.capturedLength();
         }
     }
 
     //del, add only markup, punct, num
     //TODO further improvement: spaces, punct marked as 0
 //BEGIN BEGIN HANDLING
-    QRegExp rxNonTranslatable;
+    QRegularExpression rxNonTranslatable;
     if (tryMarkup)
         rxNonTranslatable.setPattern(QStringLiteral("^((") + entry.markupExpr + QStringLiteral(")|(\\W|\\d)+)+"));
     else
@@ -825,8 +836,7 @@ CatalogString TM::targetAdapted(const TMEntry& entry, const CatalogString& ref)
         }
 
         //qCWarning(LOKALIZE_LOG)<<"old"<<oldMarkup;
-        rxNonTranslatable.indexIn(oldMarkup); //FIXME if it fails?
-        oldMarkup = rxNonTranslatable.cap(0);
+        oldMarkup = rxNonTranslatable.match(oldMarkup).captured(0); //FIXME if it fails?
         if (target.string.startsWith(oldMarkup)) {
 
             //form 'newMarkup'
@@ -838,8 +848,7 @@ CatalogString TM::targetAdapted(const TMEntry& entry, const CatalogString& ref)
                     newMarkup.append(d.diffClean.at(j));
             }
             //qCWarning(LOKALIZE_LOG)<<"new"<<newMarkup;
-            rxNonTranslatable.indexIn(newMarkup);
-            newMarkup = rxNonTranslatable.cap(0);
+            newMarkup = rxNonTranslatable.match(newMarkup).captured(0);
 
             //replace
             qCWarning(LOKALIZE_LOG) << "BEGIN HANDLING. replacing" << target.string.left(oldMarkup.size()) << "with" << newMarkup;
@@ -880,8 +889,7 @@ CatalogString TM::targetAdapted(const TMEntry& entry, const CatalogString& ref)
                 oldMarkup.append(d.diffClean.at(len + j));
         }
         //qCWarning(LOKALIZE_LOG)<<"old-"<<oldMarkup;
-        rxNonTranslatable.indexIn(oldMarkup);
-        oldMarkup = rxNonTranslatable.cap(0);
+        oldMarkup = rxNonTranslatable.match(oldMarkup).captured(0);
         if (target.string.endsWith(oldMarkup)) {
 
             //form newMarkup
@@ -893,8 +901,7 @@ CatalogString TM::targetAdapted(const TMEntry& entry, const CatalogString& ref)
                     newMarkup.append(d.diffClean.at(len + j));
             }
             //qCWarning(LOKALIZE_LOG)<<"new"<<newMarkup;
-            rxNonTranslatable.indexIn(newMarkup);
-            newMarkup = rxNonTranslatable.cap(0);
+            newMarkup = rxNonTranslatable.match(newMarkup).captured(0);
 
             //replace
             target.string.chop(oldMarkup.size());
